@@ -344,8 +344,8 @@ def _requires(modules: Sequence[str]) -> Sequence[str]:
 
         reqs = mod.requires
         if reqs is None:
-            error(f"Module {mod.name} has no REQUIRES specification")
-            sys.exit(1)
+            warning(f"Module {mod.name} has no REQUIRES specification")
+            continue
         for r in reqs:
             if r not in res:
                 res.append(r)
@@ -369,6 +369,10 @@ def module_install(*, user: bool, module: Sequence[str], parallel: bool=False) -
 
     requirements = _requires(module)
 
+    if len(requirements) == 0:
+        warning('requirements list is empty, no need to install anything')
+        return
+
     pre_cmd = [
         sys.executable, '-m', 'pip',
         'install',
@@ -376,7 +380,9 @@ def module_install(*, user: bool, module: Sequence[str], parallel: bool=False) -
     ]
 
     cmds = []
-    if parallel:
+    # disable parallel on windows, sometimes throws a
+    # '[WinError 32] The process cannot access the file because it is being used by another process'
+    if parallel and sys.platform not in ['win32', 'cygwin']:
         # todo not really sure if it's safe to install in parallel like this
         # but definitely doesn't hurt to experiment for e.g. mypy pipelines
         # pip has '--use-feature=fast-deps', but it doesn't really work
