@@ -1,11 +1,16 @@
 '''
 Unified RSS data, merged from different services I used historically
 '''
+# NOTE: you can comment out the sources you're not using
+from . import feedbin, feedly
+
 from typing import Iterable
 from .common import Subscription, compute_subscriptions
 
 
 def subscriptions() -> Iterable[Subscription]:
-    from . import feedbin, feedly
     # TODO google reader?
-    yield from compute_subscriptions(feedbin.states(), feedly.states())
+    yield from compute_subscriptions(
+        feedbin.states(),
+        feedly .states(),
+    )
